@@ -1,4 +1,4 @@
-using std::cout;  using std::cerr;  using std::endl;  using std::to_string;
+using std::cout;  using std::cerr;  using std::endl;  //using std::to_string;  // NEED DELETE, PRE-TEMPLATE C++
 
 #ifndef __CPP__INCLUDED__RPerl__DataStructure__Hash__SubTypes_cpp
 #define __CPP__INCLUDED__RPerl__DataStructure__Hash__SubTypes_cpp 0.003_000
