@@ -1,7 +1,7 @@
 using std::cout;  using std::cerr;  using std::endl;
 
 #ifndef __CPP__INCLUDED__RPerl__DataType__Integer_cpp
-#define __CPP__INCLUDED__RPerl__DataType__Integer_cpp 0.008_000
+#define __CPP__INCLUDED__RPerl__DataType__Integer_cpp 0.011_100
 
 // [[[ INCLUDES ]]]
 #include <RPerl/DataType/Integer.h>  // -> NULL (relies on native C type)
@@ -176,13 +176,20 @@ SV* integer_to_string(SV* input_integer) {
     // DEV NOTE: disable old stringify w/out underscores
 //	return(newSVpvf("%"INTEGER"", (integer)SvIV(input_integer)));
 
+    fprintf(stderr, "in CPPOPS_PERLTYPES integer_to_string(), about to call integer_to_string_CPPTYPES() & return value...\n");
     return(newSVpv((const char *)((integer_to_string_CPPTYPES((integer)SvIV(input_integer))).c_str()), 0));
 }
 
 # elif defined __CPP__TYPES
 
+string to_string(integer input_integer) {
+    fprintf(stderr, "in CPPOPS_CPPTYPES to_string(), about to call integer_to_string & return value...\n");
+    return(integer_to_string(input_integer));
+}
+
 // DEV NOTE, CORRELATION #rp010: shim CPPTYPES sub
 string integer_to_string(integer input_integer) {
+    fprintf(stderr, "in CPPOPS_CPPTYPES integer_to_string(), about to call integer_to_string_CPPTYPES() & return value...\n");
     return(integer_to_string_CPPTYPES(input_integer));
 }
 
@@ -193,7 +200,7 @@ string integer_to_string(integer input_integer) {
 // DEV NOTE, CORRELATION #rp010: the real CPPTYPES sub (below) is called by the wrapper PERLTYPES sub and shim CPPTYPES subs (above), moved outside #ifdef blocks
 string integer_to_string_CPPTYPES(integer input_integer)
 {
-//    fprintf(stderr, "in CPPOPS_CPPTYPES integer_to_string_CPPTYPES(), top of subroutine, received unformatted input_integer = %"INTEGER"\n", input_integer);
+    fprintf(stderr, "in CPPOPS_CPPTYPES integer_to_string_CPPTYPES(), top of subroutine, received unformatted input_integer = %"INTEGER"\n", input_integer);
 //    fprintf(stderr, "in CPPOPS_CPPTYPES integer_to_string_CPPTYPES()...\n");
 
     std::ostringstream output_stream;
@@ -209,6 +216,17 @@ string integer_to_string_CPPTYPES(integer input_integer)
     boolean is_negative = 0;
     if (input_integer < 0) { is_negative = 1; }
 
+// [ INTENTIONALLY LEFT BLANK TO ALIGN WITH Number.cpp ]
+
+
+
+
+
+
+
+
+// [ INTENTIONALLY LEFT BLANK TO ALIGN WITH Number.cpp ]
+
     std::reverse(output_string.begin(), output_string.end());
 
 //    fprintf(stderr, "in CPPOPS_CPPTYPES integer_to_string_CPPTYPES(), have reversed output_string = %s\n", output_string.c_str());
@@ -234,6 +252,20 @@ string integer_to_string_CPPTYPES(integer input_integer)
 
 //    fprintf(stderr, "in CPPOPS_CPPTYPES integer_to_string_CPPTYPES(), have unreversed output_string_underscores = %s\n", output_string_underscores.c_str());
 
+// [ INTENTIONALLY LEFT BLANK TO ALIGN WITH Number.cpp ]
+
+
+
+
+
+
+
+
+
+
+
+// [ INTENTIONALLY LEFT BLANK TO ALIGN WITH Number.cpp ]
+
     if (is_negative) { output_string_underscores = '-' + output_string_underscores; }
 
     return output_string_underscores;
