@@ -3,7 +3,7 @@ package RPerl::DataType::Scalar;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.005_000;
+our $VERSION = 0.006_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::DataType);
@@ -18,6 +18,7 @@ use RPerl::DataType;
 use constant INFINITY => my string $TYPED_INFINITY = 'inf';
 
 # [[[ SUB-TYPES ]]]
+
 # a scalartype is a known, non-void data type, meaning a number or a string
 # DEV NOTE: do NOT overload Perl's 'scalar' keyword!!!
 package  # hide from PAUSE indexing
@@ -26,4 +27,11 @@ use strict;
 use warnings;
 use parent qw(RPerl::DataType::Scalar);
 
+# method with scalartype return type
+package  # hide from PAUSE indexing
+    scalartype::method;
+use strict;
+use warnings;
+use parent -norequire, qw(method);
+
 1;  # end of class
