@@ -3,7 +3,7 @@ package RPerl::DataType::Unknown;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.002_000;
+our $VERSION = 0.003_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::DataType);
@@ -15,6 +15,7 @@ use RPerl::DataType;
 ## no critic qw(Capitalization ProhibitMultiplePackages ProhibitReusedNames)  # SYSTEM DEFAULT 3: allow multiple & lower case package names
 
 # [[[ SUB-TYPES ]]]
+
 # unknown means it could be any data type or data structure
 package  # hide from PAUSE indexing
     unknown;
@@ -22,4 +23,11 @@ use strict;
 use warnings;
 use parent qw(RPerl::DataType::Unknown);
 
+# method with unknown return type
+package  # hide from PAUSE indexing
+    unknown::method;
+use strict;
+use warnings;
+use parent -norequire, qw(method);
+
 1;  # end of class
