@@ -3,7 +3,7 @@ package RPerl::DataType::Void;
 use strict;
 use warnings;
 use RPerl::AfterSubclass;
-our $VERSION = 0.002_000;
+our $VERSION = 0.003_000;
 
 # [[[ OO INHERITANCE ]]]
 use parent qw(RPerl::DataType);
@@ -15,6 +15,7 @@ use RPerl::DataType;
 ## no critic qw(Capitalization ProhibitMultiplePackages ProhibitReusedNames)  # SYSTEM DEFAULT 3: allow multiple & lower case package names
 
 # [[[ SUB-TYPES ]]]
+
 # void means no type, void does NOT mean unknown data type, that is RPerl::DataType::Unknown
 package  # hide from PAUSE indexing
     void;
@@ -22,4 +23,11 @@ use strict;
 use warnings;
 use parent qw(RPerl::DataType::Void);
 
+# method with void return type
+package  # hide from PAUSE indexing
+    void::method;
+use strict;
+use warnings;
+use parent -norequire, qw(method);
+
 1;  # end of class
