@@ -3,7 +3,7 @@ package RPerl::Exporter;
 use strict;
 use warnings;
 use RPerl::Config;
-our $VERSION = 0.006_000;
+our $VERSION = 0.009_000;
 
 # [[[ OO INHERITANCE ]]]
 #use parent qw(RPerl::CompileUnit::Module::Class);
@@ -44,7 +44,13 @@ our $SUPPORTED_ALL = [
         integer_hashref
         number_hashref
         string_hashref
-        )
+        integer_arrayref_hashref
+        number_arrayref_hashref
+        string_arrayref_hashref
+        integer_arrayref_hashref_hashref
+        number_arrayref_hashref_hashref
+        string_arrayref_hashref_hashref
+    )
 ];
 #our string_arrayref $SUPPORTED_SPECIAL = [
 our $SUPPORTED_SPECIAL = [
@@ -52,7 +58,7 @@ our $SUPPORTED_SPECIAL = [
         sse_number_pair
         gmp_integer
         gsl_matrix
-        )
+    )
 ];
 
 # [[[ SUBROUTINES & OO METHODS ]]]
@@ -501,3 +507,4 @@ sub import {
 }
 
 1;
+
