@@ -1,4 +1,12 @@
 #!/usr/bin/env perl
+
+# [[[ PREPROCESSOR ]]]
+# <<< EXECUTE_SUCCESS: "before loop" >>>
+# <<< EXECUTE_SUCCESS: "$n = 0.7391304347" >>>
+# <<< EXECUTE_SUCCESS: "$n = 0.0246913580" >>>
+# <<< EXECUTE_SUCCESS: "$n = 21.12" >>>
+# <<< EXECUTE_SUCCESS: "after loop" >>>
+
 # [[[ HEADER ]]]
 use RPerl;
 use strict;
@@ -11,7 +19,11 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
+print 'before loop', "\n";
+
 my number_arrayref $n_array = [ 17 / 23, 42 / 1_701, 21.12 ];
 foreach my number $n ( @{$n_array} ) {
     print '$n = ', $n, "\n";
 }
+
+print 'after loop', "\n";
