@@ -1,11 +1,9 @@
 #!/usr/bin/env perl
 
-# DEV NOTE, CORRELATION #rp031: NEED UPGRADE: implement proper @array vs $arrayref, %hash vs $hashref, dereferencing, etc.
-
 # [[[ PREPROCESSOR ]]]
 # <<< EXECUTE_SUCCESS: "in main(), have pre-modify $arrayref_1D = [ 0, 2, 4, 6, 8 ]" >>>
-# <<< EXECUTE_SUCCESS: "in modify_arrayref, received $arrayref_1D_input =      [ 0, 2, 4, 6, 8 ]" >>>
-# <<< EXECUTE_SUCCESS: "in modify_arrayref, have modified $arrayref_1D_input = [ 0, 2, 99, 6, 8 ]" >>>
+# <<< EXECUTE_SUCCESS: "in modify_arrayref(), received $arrayref_1D_input =      [ 0, 2, 4, 6, 8 ]" >>>
+# <<< EXECUTE_SUCCESS: "in modify_arrayref(), have modified $arrayref_1D_input = [ 0, 2, 99, 6, 8 ]" >>>
 # <<< EXECUTE_SUCCESS: "in main(), have post-modify $arrayref_1D = [ 0, 2, 99, 6, 8 ]" >>>
 
 # [[[ HEADER ]]]
@@ -24,10 +22,10 @@ sub modify_arrayref {
     { my void $RETURN_TYPE };
     ( my integer_arrayref $arrayref_1D_input ) = @ARG;
 
-    print 'in modify_arrayref, received $arrayref_1D_input =      ', integer_arrayref_to_string($arrayref_1D_input), "\n";
+    print 'in modify_arrayref(), received $arrayref_1D_input =      ', integer_arrayref_to_string($arrayref_1D_input), "\n";
     $arrayref_1D_input->[2] = 99;
 
-    print 'in modify_arrayref, have modified $arrayref_1D_input = ', integer_arrayref_to_string($arrayref_1D_input), "\n";
+    print 'in modify_arrayref(), have modified $arrayref_1D_input = ', integer_arrayref_to_string($arrayref_1D_input), "\n";
     return;
 }
 
