@@ -9,6 +9,6 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our integer $empty_sub = sub { return -2; };
+sub empty_sub { { my integer $RETURN_TYPE }; return -2; }
 
 1;    # end of package
