@@ -12,8 +12,6 @@ our $VERSION = 0.001_000;
 ## no critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ SUBROUTINES ]]]
-our number $empty_sub = sub {
-    return -23_456_89.234_56;
-};
+sub empty_sub { { my number $RETURN_TYPE }; return -23_456_89.234_56; }
 
 1;    # end of package
