@@ -17,7 +17,10 @@ our hashref $properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-sub empty_method { { my void::method $RETURN_TYPE }; return 2; }
+sub empty_method {
+    { my void::method $RETURN_TYPE };
+    return 2;
+}
 
 1;    # end of class
 
@@ -40,7 +43,10 @@ our hashref $properties
     = { empty_property_additional => my integer $TYPED_empty_property_additional = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-sub empty_method_additional { { my void::method $RETURN_TYPE }; return 2; }
+sub empty_method_additional {
+    { my void::method $RETURN_TYPE };
+    return 2;
+}
 
 1;    # end of class
 
