@@ -1,11 +1,11 @@
 #!/usr/bin/env perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< EXECUTE_SUCCESS: 'foo-' >>>
-# <<< EXECUTE_SUCCESS: 'quux' >>>
-# <<< EXECUTE_SUCCESS: 'zorg+' >>>
-# <<< EXECUTE_SUCCESS: 'munge/' >>>
-# <<< EXECUTE_SUCCESS: 'frob*' >>>
+# <<< EXECUTE_SUCCESS: '$s = foo-' >>>
+# <<< EXECUTE_SUCCESS: '$s = quux' >>>
+# <<< EXECUTE_SUCCESS: '$s = zorg+' >>>
+# <<< EXECUTE_SUCCESS: '$s = munge/' >>>
+# <<< EXECUTE_SUCCESS: '$s = frob*' >>>
 
 # [[[ HEADER ]]]
 use RPerl;
@@ -19,7 +19,7 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-my string_arrayref $s_array = [qw(foo- quux zorg+ munge/ frob*)];
-foreach my string $s ( @{$s_array} ) {
+my string_array @s_array = qw(foo- quux zorg+ munge/ frob*);
+foreach my string $s ( @s_array ) {
     print '$s = ', $s, "\n";
 }
