@@ -16,7 +16,7 @@ our $VERSION = 0.001_000;
 
 # [[[ OPERATIONS ]]]
 
-my string_arrayref $s_array = [qw(foo-1bar-5bat qu23ux zorg0+blop+0frun munge4/4sqap6/6cruft 88frob*99grul99*jick88 w`~!@$%^&*_=[]{}|;:'",.<>?)];
-foreach my string $s ( @{$s_array} ) {
+my string_array @s_array = qw(foo-1bar-5bat qu23ux zorg0+blop+0frun munge4/4sqap6/6cruft 88frob*99grul99*jick88 w`~!@$%^&*_=[]{}|;:'",.<>?);
+foreach my string $s ( @s_array ) {
     print '$s = ', $s, "\n";
 }
