@@ -10,6 +10,4 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ OPERATIONS ]]]
-
-# DEV NOTE: DO NOT RUN PERLTIDY ON THIS FILE!  the line below should read 'croak -1;' not 'croak - 1;'
-croak -1;
+croak 23;
