@@ -10,8 +10,9 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-sub foo { { my boolean $RETURN_TYPE }; return 0; }
+
+# DEV NOTE: DO NOT RUN PERLTIDY ON THIS FILE!  the line below should read 'return ();' not 'return();'
+sub foo { { my void $RETURN_TYPE }; return (); }
 
 # [[[ OPERATIONS ]]]
 foo();
-
