@@ -2,7 +2,7 @@
 
 # [[[ PREPROCESSOR ]]]
 # <<< PARSE_ERROR: 'ERROR ECOPARP00' >>>
-# <<< PARSE_ERROR: 'Unexpected Token:  &' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  *' >>>
 
 # [[[ HEADER ]]]
 use RPerl;
@@ -15,8 +15,7 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-sub foo { { my boolean $RETURN_TYPE }; return & 1; }
+sub foo { { my boolean $RETURN_TYPE }; return * 0; }
 
 # [[[ OPERATIONS ]]]
 foo();
-
