@@ -1,8 +1,8 @@
 #!/usr/bin/env perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< PARSE_ERROR: 'ERROR ECOPAPC02' >>>
-# <<< PARSE_ERROR: 'Perl::Critic::Policy::ValuesAndExpressions::ProhibitMismatchedOperators' >>>
+# <<< PARSE_ERROR: 'ERROR ECOPARP00' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  -' >>>
 
 # [[[ HEADER ]]]
 use RPerl;
@@ -15,7 +15,7 @@ our $VERSION = 0.001_000;
 ## no critic qw(RequireInterpolationOfMetachars)  # USER DEFAULT 2: allow single-quoted control characters & sigils
 
 # [[[ SUBROUTINES ]]]
-sub foo { { my string $RETURN_TYPE }; return - 'ahoy'; }
+sub foo { { my number $RETURN_TYPE }; return - 234_567.890_12; }
 
 # [[[ OPERATIONS ]]]
 foo();
