@@ -18,6 +18,9 @@ our hashref $properties
     = { some_integer => my integer $TYPED_some_integer = 23 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-sub properties_stnv { { my string::method $RETURN_TYPE }; return main::scope_type_name_value($properties); }
+sub properties_stnv {
+    { my string::method $RETURN_TYPE };
+    return main::scope_type_name_value($properties);
+}
 
 1;    # end of class
