@@ -9,6 +9,6 @@ use warnings;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub {;};
+sub empty_sub { { my void $RETURN_TYPE };; return; }
 
 1;                  # end of package
